==> dolfin_0.9.7.orig.tar.gz: dolfin-0.9.7/dolfin/la/EpetraFactory.cpp <==
// Copyright (C) 2008 Martin Sandve Alnes, Kent-Andre Mardal and Johannes Ring.
// Licensed under the GNU LGPL Version 2.1.
//
// First added:  2008-04-21
// Last changed: 2008-09-28

#ifdef HAS_TRILINOS

#include "EpetraSparsityPattern.h"
#include "EpetraMatrix.h"
#include "EpetraVector.h"
#include "EpetraFactory.h"

#include <Epetra_SerialComm.h>

using namespace dolfin;

//-----------------------------------------------------------------------------
EpetraFactory:: EpetraFactory()
{
  comm = new Epetra_SerialComm();
}
//-----------------------------------------------------------------------------
EpetraFactory:: ~EpetraFactory()
{
  delete comm;
}
//-----------------------------------------------------------------------------
EpetraMatrix* EpetraFactory::create_matrix() const
{
  return new EpetraMatrix();
}
//-----------------------------------------------------------------------------
EpetraVector* EpetraFactory::create_vector() const
{
  return new EpetraVector();
}
//-----------------------------------------------------------------------------
EpetraVector* EpetraFactory::create_local_vector() const
{
  return new EpetraVector();
}
//-----------------------------------------------------------------------------
EpetraSparsityPattern* EpetraFactory::create_pattern() const
{
  return new EpetraSparsityPattern();
}
//-----------------------------------------------------------------------------
Epetra_SerialComm& EpetraFactory::getSerialComm()
{
  return *comm;
}
//-----------------------------------------------------------------------------

// Singleton instance
EpetraFactory EpetraFactory::factory;

#endif

==> dolfin_0.9.8.orig.tar.gz: dolfin-0.9.8/dolfin/la/EpetraFactory.cpp <==
// Copyright (C) 2008 Martin Sandve Alnes, Kent-Andre Mardal and Johannes Ring.
// Licensed under the GNU LGPL Version 2.1.
//
// First added:  2008-04-21
// Last changed: 2008-09-28

#ifdef HAS_TRILINOS

#include <Epetra_MpiComm.h>
#include <Epetra_SerialComm.h>

#include "dolfin/main/MPI.h"
#include "EpetraSparsityPattern.h"
#include "SparsityPattern.h"
#include "EpetraMatrix.h"
#include "EpetraVector.h"
#include "EpetraVector.h"

#include "EpetraFactory.h"

using namespace dolfin;

// Singleton instance
EpetraFactory EpetraFactory::factory;

//-----------------------------------------------------------------------------
EpetraFactory::EpetraFactory()
{
  serial_comm = new Epetra_SerialComm();

  // Why does this not work with dolfin::MPICommunicator?
  mpi_comm = new Epetra_MpiComm(MPI_COMM_WORLD);
}
//-----------------------------------------------------------------------------
EpetraFactory::~EpetraFactory()
{
  delete serial_comm;
  delete mpi_comm;
}
//-----------------------------------------------------------------------------
EpetraMatrix* EpetraFactory::create_matrix() const
{
  return new EpetraMatrix();
}
//-----------------------------------------------------------------------------
EpetraVector* EpetraFactory::create_vector() const
{
  return new EpetraVector("global");
}
//-----------------------------------------------------------------------------
EpetraVector* EpetraFactory::create_local_vector() const
{
  return new EpetraVector("local");
}
//-----------------------------------------------------------------------------
SparsityPattern* EpetraFactory::create_pattern() const
{
  return new SparsityPattern(SparsityPattern::sorted);
}
//-----------------------------------------------------------------------------
Epetra_SerialComm& EpetraFactory::get_serial_comm() const
{
  return *serial_comm;
}
//-----------------------------------------------------------------------------
Epetra_MpiComm& EpetraFactory::get_mpi_comm() const
{
  return *mpi_comm;
}
//-----------------------------------------------------------------------------

#endif
